0.2
* initial commit
* renamed `g_analytics_writer`, was `gaq_hub`
* dropped pylons support
* the package now handles an internal format for tracking the data, and writes
  in one of multiple google analytics formats
